@@ -62,7 +62,7 @@ ena.conversations = function(set, units, units.by=NULL, codes=NULL, conversation
   }
 
   # rawAcc$KEYCOL = merge_columns_c(rawAcc, conversation.by)
-  rawAcc2$KEYCOL = merge_columns_c(rawAcc2, conversation.by)
+  rawAcc2$KEYCOL = merge_columns_c(rawAcc2, conversation.by, sep = "::")
 
   # conversationsTable = rawAcc[, paste(.I, collapse = ","), by = c(conversation.by)]
   conversationsTable2 = rawAcc2[, paste(.I, collapse = ","), by = c(conversation.by)]
@@ -71,10 +71,10 @@ ena.conversations = function(set, units, units.by=NULL, codes=NULL, conversation
   rows2 = lapply(conversationsTable2$V1, function(x) as.numeric(unlist(strsplit(x, split=","))))
   # browser()
   # names(rows) = merge_columns_c(conversationsTable,conversation.by); #unique(rawAcc[,KEYCOL])
-  names(rows2) = merge_columns_c(conversationsTable2,conversation.by); #unique(rawAcc[,KEYCOL])
+  names(rows2) = merge_columns_c(conversationsTable2,conversation.by, sep = "::"); #unique(rawAcc[,KEYCOL])
 
   # unitRows = merge_columns_c(rawAcc[,c(units.by),with=F], units.by)
-  unitRows2 = merge_columns_c(rawAcc2[,c(units.by),with=F], units.by)
+  unitRows2 = merge_columns_c(rawAcc2[,c(units.by),with=F], units.by, sep = "::")
 
   # adjCol = set$enadata$adjacency.matrix[1,] %in%  codes[1] & set$enadata$adjacency.matrix[2,] %in% codes[2]
   # adjColName = paste("adjacency.code.", which(adjCol), sep = "")
