@@ -20,6 +20,25 @@ find_code_cols <- function(x) {
    })
 }
 
+#' Find Binary Columns
+#'
+#' Identifies columns in a data.frame or data.table that are binary (i.e., contain only two unique values), optionally including logical columns.
+#'
+#' @param x A data.frame or data.table to search for binary columns.
+#' @param include_logical Logical. If TRUE, logical columns are also considered binary. Default is FALSE.
+#'
+#' @return A character vector of column names that are binary, or NULL if none are found.
+#' @export
+#'
+#' @examples
+#' df <- data.frame(a = c(0, 1, 1), b = c(TRUE, FALSE, TRUE), c = c(1, 2, 3))
+#' find_binary_cols(df)
+#' find_binary_cols(df, include_logical = TRUE)
+find_binary_cols <- function(x, include_logical = FALSE) {
+   nm <- colnames(x)[sapply(x, is_binary_col, include_logical)];
+   if(length(nm) > 0) nm else NULL;
+}
+
 #' Find dimension columns
 #'
 #' @param x data.table (or frame) to search for columns of class ena.dimension
@@ -96,6 +115,29 @@ remove_meta_data <- function(x) {
 
    vals
 }
+
+#' Multiply ena.matrix objects
+#' Element-wise multiplication of dimension columns in an ena.matrix by another ena.matrix or numeric matrix.
+#' If e2 is an ena.matrix, it is converted to a standard matrix before multiplication.
+#' The multiplication is applied only to the dimension columns of e1, while other columns remain
+#' unchanged.
+#' 
+#' @param e1 An ena.matrix object whose dimension columns will be multiplied.
+#' @param e2 An ena.matrix or numeric matrix to multiply with the dimension columns of
+#' e1.
+#' 
+#' @return An ena.matrix object with the dimension columns of e1 multiplied by e2.
+#' @exportS3Method "*" ena.matrix
+"*.ena.matrix" <- function (e1, e2) {
+   e2m <- e2
+   if(is(e2, "ena.matrix")) {
+      e2m <- as.matrix(e2)
+   }
+   
+   dim_cols <- colnames(e1)[find_dimension_cols(e1)]
+   e1[, (dim_cols) := Map(function(col, mult) col * mult, .SD, as.data.frame(e2m)), .SDcols = dim_cols]
+}
+
 # "$.ena.plot" <- function(x, i) {
 #  browser()
 # }
@@ -174,6 +216,8 @@ print.ena.set <- function(x, ..., plot = FALSE, set = TRUE) {
       }
       base::print(x.unclass)
    }
+
+   invisible(x);
 }
 
 #' Title
@@ -293,19 +337,39 @@ means_rotate <- function(x, on = NULL) {
 }
 
 .return <- function(x, invisible = T, from_plot = F) {
-   # browser()
    x$`_plot_op` = from_plot
-# if() {
-#       print(x$plots)
-#    }
+   if(isTRUE(from_plot)) {
+      
+   }
 
    if(invisible == T) {
       invisible(x)
-   } else {
+   }
+   else {
       return(x)
    }
 }
 
+is_logical_col <- function(col) {
+  n_cols = col == TRUE | col == FALSE;
+  is_col <- is.logical(col) & all(n_cols);
+
+  return(is_col);
+}
+
+is_binary_col <- function(col, include_logical = TRUE) {
+  n_cols = col == 1 | col == 0;
+  is_col <- is.numeric(col) && all(is.wholenumber(col) & all(n_cols));
+
+  if(isTRUE(include_logical)) {
+    is_col <- is_col | is_logical_col(col);
+  }
+
+  return(is_col);
+}
+
+is.wholenumber <- function(x, tol = .Machine$double.eps^0.5)  abs(x - round(x)) < tol
+
 
 #' Extract points easily
 #'
@@ -334,3 +398,4 @@ means_rotate <- function(x, on = NULL) {
 #   class(x_) <- orig.class
 #   x_
 # }
+
